@@ -1,6 +1,6 @@
 /*
  * pepper - SCM statistics report generator
- * Copyright (C) 2010-2012 Jonas Gehring
+ * Copyright (C) 2010-present Jonas Gehring
  *
  * Released under the GNU General Public License, version 3.
  * Please see the COPYING file in the source distribution for license
@@ -34,7 +34,7 @@ class MercurialBackend : public Backend
 		std::string mainBranch();
 		std::vector<std::string> branches();
 		std::vector<Tag> tags();
-		Diffstat diffstat(const std::string &id);
+		DiffstatPtr diffstat(const std::string &id);
 		std::vector<std::string> tree(const std::string &id = std::string());
 		std::string cat(const std::string &path, const std::string &id = std::string());
 
