@@ -1,6 +1,6 @@
 /*
  * pepper - SCM statistics report generator
- * Copyright (C) 2010-2012 Jonas Gehring
+ * Copyright (C) 2010-present Jonas Gehring
  *
  * Released under the GNU General Public License, version 3.
  * Please see the COPYING file in the source distribution for license
@@ -25,7 +25,6 @@
 #include <svn_path.h>
 #include <svn_pools.h>
 #include <svn_ra.h>
-#include <svn_sorts.h>
 #include <svn_time.h>
 #include <svn_utf.h>
 
@@ -44,6 +43,32 @@
 #include "backends/subversion_p.h"
 
 
+namespace {
+
+struct HashKey {
+	const char *data;
+	apr_ssize_t len;
+
+	HashKey(const char *data, apr_ssize_t len) : data(data), len(len) { }
+
+	bool operator<(const HashKey &other) const {
+		return memcmp(data, other.data, std::min(len, other.len)) < 0;
+	}
+};
+
+// Returns a vector of all keys in a APR hash
+std::vector<HashKey> getHashKeys(apr_hash_t *hash, apr_pool_t *pool)
+{
+	std::vector<HashKey> keys;
+	for (apr_hash_index_t *hi = apr_hash_first(pool, hash); hi; hi = apr_hash_next(hi)) {
+		keys.push_back(HashKey((const char *)apr_hash_this_key(hi), apr_hash_this_key_len(hi)));
+	}
+	return keys;
+}
+
+} // anonymous namespace
+
+
 // Constructor
 SvnConnection::SvnConnection()
 	: pool(NULL), ctx(NULL), ra(NULL), url(NULL), root(NULL), prefix(NULL)
@@ -249,7 +274,7 @@ public:
 		m_queue.put(revisions);
 	}
 
-	bool get(const std::string &revision, Diffstat *dest)
+	bool get(const std::string &revision, DiffstatPtr *dest)
 	{
 		return m_queue.getResult(revision, dest);
 	}
@@ -260,7 +285,7 @@ public:
 	}
 
 private:
-	JobQueue<std::string, Diffstat> m_queue;
+	JobQueue<std::string, DiffstatPtr> m_queue;
 	std::vector<SvnDiffstatThread *> m_threads;
 };
 
@@ -285,9 +310,9 @@ SubversionBackend::SvnLogIterator::~SvnLogIterator()
 // Returns the next revision IDs, or an empty vector
 bool SubversionBackend::SvnLogIterator::nextIds(std::queue<std::string> *queue)
 {
-	m_mutex.lock();
+	sys::parallel::MutexLocker locker(&m_mutex);
 	while (m_index >= m_ids.size() && !m_finished) {
-		m_cond.wait(&m_mutex);
+		m_cond.wait(locker.mutex());
 	}
 
 	if (m_failed) {
@@ -300,7 +325,6 @@ bool SubversionBackend::SvnLogIterator::nextIds(std::queue<std::string> *queue)
 	while (m_index < m_ids.size()) {
 		queue->push(m_ids[m_index++]);
 	}
-	m_mutex.unlock();
 	return true;
 }
 
@@ -826,25 +850,26 @@ std::vector<Tag> SubversionBackend::tags()
 		throw PEX(SvnConnection::strerr(err));
 	}
 
-	apr_array_header_t *array = svn_sort__hash(dirents, &svn_sort_compare_items_lexically,  pool);
-	for (int i = 0; i < array->nelts; i++) {
-		svn_sort__item_t *item = &APR_ARRAY_IDX(array, i, svn_sort__item_t);
-		svn_dirent_t *dirent = (svn_dirent_t *)apr_hash_get(dirents, item->key, item->klen);
+	for (apr_hash_index_t *hi = apr_hash_first(pool, dirents); hi; hi = apr_hash_next(hi)) {
+		const char *key;
+		svn_dirent_t *dirent;
+		apr_hash_this(hi, (const void **)&key, NULL, (void **)&dirent);
 		if (dirent->kind == svn_node_dir) {
-			tags.push_back(Tag(str::itos(dirent->created_rev), (const char *)item->key));
+			tags.push_back(Tag(str::itos(dirent->created_rev), key));
 		}
 	}
+	std::sort(tags.begin(), tags.end());
 
 	svn_pool_destroy(pool);
 	return tags;
 }
 
 // Returns a diffstat for the specified revision
-Diffstat SubversionBackend::diffstat(const std::string &id)
+DiffstatPtr SubversionBackend::diffstat(const std::string &id)
 {
 	if (m_prefetcher && m_prefetcher->willFetch(id)) {
 		PTRACE << "Revision " << id << " will be prefetched" << endl;
-		Diffstat stat;
+		DiffstatPtr stat;
 		if (!m_prefetcher->get(id, &stat)) {
 			throw PEX(std::string("Failed to retrieve diffstat for revision ") + id);
 		}
@@ -868,13 +893,13 @@ Diffstat SubversionBackend::diffstat(const std::string &id)
 	PDEBUG << "Fetching revision " << id << " manually" << endl;
 
 	apr_pool_t *pool = svn_pool_create(d->pool);
-	Diffstat stat = SvnDiffstatThread::diffstat(d, r1, r2, pool);
+	DiffstatPtr stat = SvnDiffstatThread::diffstat(d, r1, r2, pool);
 	svn_pool_destroy(pool);
 	return stat;
 }
 
 // Filters a diffstat by prefix
-void SubversionBackend::filterDiffstat(Diffstat *stat)
+void SubversionBackend::filterDiffstat(DiffstatPtr stat)
 {
 	// Strip prefix
 	if (d->prefix && strlen(d->prefix)) {
@@ -921,15 +946,16 @@ std::vector<std::string> SubversionBackend::tree(const std::string &id)
 
 		std::string prefix = (node.empty() ? "" : node + "/");
 		std::stack<std::pair<std::string, int> > next;
-		apr_array_header_t *array = svn_sort__hash(dirents, &svn_sort_compare_items_lexically,  iterpool);
-		for (int i = 0; i < array->nelts; i++) {
-			svn_sort__item_t *item = &APR_ARRAY_IDX(array, i, svn_sort__item_t);
-			svn_dirent_t *dirent = (svn_dirent_t *)apr_hash_get(dirents, item->key, item->klen);
-			if (str::endsWith(node, (const char *)item->key) || str::endsWith(d->url, (const char *)item->key)) {
+
+		std::vector<HashKey> keys = getHashKeys(dirents, iterpool);
+		std::sort(keys.begin(), keys.end());
+		for (size_t i = 0; i < keys.size(); i++) {
+			svn_dirent_t *dirent = (svn_dirent_t *)apr_hash_get(dirents, keys[i].data, keys[i].len);
+			if (str::endsWith(node, keys[i].data) || str::endsWith(d->url, keys[i].data)) {
 				continue;
 			}
 			if (dirent->kind == svn_node_file || dirent->kind == svn_node_dir) {
-				next.push(std::pair<std::string, int>(prefix + (const char *)item->key, dirent->kind));
+				next.push(std::pair<std::string, int>(prefix + keys[i].data, dirent->kind));
 			}
 		}
 		while (!next.empty()) {
