@@ -1,6 +1,6 @@
 /*
  * pepper - SCM statistics report generator
- * Copyright (C) 2010-2012 Jonas Gehring
+ * Copyright (C) 2010-present Jonas Gehring
  *
  * Released under the GNU General Public License, version 3.
  * Please see the COPYING file in the source distribution for license
@@ -43,6 +43,12 @@ std::string Tag::name() const
 	return m_name;
 }
 
+// Compares tags by their name
+bool Tag::operator<(const Tag &other) const
+{
+	return m_name < other.m_name;
+}
+
 /*
  * Lua binding
  */
