@@ -1,6 +1,6 @@
 /*
  * pepper - SCM statistics report generator
- * Copyright (C) 2010-2012 Jonas Gehring
+ * Copyright (C) 2010-present Jonas Gehring
  *
  * Released under the GNU General Public License, version 3.
  * Please see the COPYING file in the source distribution for license
@@ -189,16 +189,16 @@ TEST_CASE("subversion/revisions", "Revision retrieval")
 	REQUIRE(rev->m_author == "jonas");
 	REQUIRE(rev->m_message == "Use real names");
 	REQUIRE(rev->m_date == 1299447342);
-	Diffstat d = rev->m_diffstat;
-	REQUIRE(d.m_stats.size() == 2);
-	REQUIRE(d.m_stats["trunk/dude"].ladd == 0);
-	REQUIRE(d.m_stats["trunk/dude"].ldel == 4);
-	REQUIRE(d.m_stats["trunk/dude"].cadd == 0);
-	REQUIRE(d.m_stats["trunk/dude"].cdel == 240);
-	REQUIRE(d.m_stats["trunk/jeffrey"].ladd == 4);
-	REQUIRE(d.m_stats["trunk/jeffrey"].ldel == 0);
-	REQUIRE(d.m_stats["trunk/jeffrey"].cadd == 240);
-	REQUIRE(d.m_stats["trunk/jeffrey"].cdel == 0);
+	DiffstatPtr d = rev->m_diffstat;
+	REQUIRE(d->m_stats.size() == 2);
+	REQUIRE(d->m_stats["trunk/dude"].ladd == 0);
+	REQUIRE(d->m_stats["trunk/dude"].ldel == 4);
+	REQUIRE(d->m_stats["trunk/dude"].cadd == 0);
+	REQUIRE(d->m_stats["trunk/dude"].cdel == 240);
+	REQUIRE(d->m_stats["trunk/jeffrey"].ladd == 4);
+	REQUIRE(d->m_stats["trunk/jeffrey"].ldel == 0);
+	REQUIRE(d->m_stats["trunk/jeffrey"].cadd == 240);
+	REQUIRE(d->m_stats["trunk/jeffrey"].cdel == 0);
 	delete rev;
 }
 
@@ -269,6 +269,32 @@ TEST_CASE("subversion/tags", "Tag listing")
 	REQUIRE(tags[0].name() == dtags[0].name());
 }
 
+TEST_CASE("subversion/tree", "Tree listing")
+{
+	std::string repo = setupTestRepo();
+
+	Options options;
+	options.m_options["repository"] = repo;
+	options.m_options["cache"] = "false";
+	Logger::setLevel(Logger::Debug);
+	Logger::setOutput(std::cout);
+	SubversionBackend backend(options);
+	backend.init();
+
+	std::vector<std::string> dtree;
+	dtree.push_back("branches/swearing/jeffrey");
+	dtree.push_back("branches/swearing/other");
+	dtree.push_back("branches/swearing/walter");
+	dtree.push_back("tags/1.0/jeffrey");
+	dtree.push_back("tags/1.0/other");
+	dtree.push_back("tags/1.0/walter");
+	dtree.push_back("trunk/jeffrey");
+	dtree.push_back("trunk/other");
+	dtree.push_back("trunk/walter");
+	std::vector<std::string> tree = backend.tree();
+	REQUIRE(tree == dtree);
+}
+
 
 /*
  * Test repository dump
