@@ -1,6 +1,6 @@
 /*
  * pepper - SCM statistics report generator
- * Copyright (C) 2010-2012 Jonas Gehring
+ * Copyright (C) 2010-present Jonas Gehring
  *
  * Released under the GNU General Public License, version 3.
  * Please see the COPYING file in the source distribution for license
@@ -19,7 +19,7 @@
 // Program entry point
 int main(int, char **)
 {
-	std::map<std::string, Diffstat::Stat> stat = DiffParser::parse(std::cin).stats();
+	std::map<std::string, Diffstat::Stat> stat = DiffParser::parse(std::cin)->stats();
 
 	uint64_t ins = 0, del = 0;
 	for (std::map<std::string, Diffstat::Stat>::const_iterator it = stat.begin(); it != stat.end(); ++it) {
